% Program to interface with Ansys HFSS IE (or HFSS) and record the E_total in the far field 
% to see the nulling over an observation window at a finite distance

clc; clear all;
format long;            % prints out more digits
format compact;         % makes the output more compact

ProjectName = 'Scattrn_Redctn_2dipolesInfGrnd_ImgThry_3';
%ProjectName = 'Scattrn_Redctn_2dipolesInfGrnd_OnlyIntrDip';

%------ Variables -----------
% Lx = 5000; %30;  % in millimeters
% Ly = 5000; %30;  % in millimeters
% Nx = 100;
% Ny = 100;
Lx = 2000;    % in millimeters
Ly = 2000;    % in millimeters
Nx = 40;
Ny = 40;
Lxi = Lx/Nx;
Lyi = Ly/Ny;
z0 = 1920; %50000; %1900; % in millimeters
Ex_mag = zeros(Nx*2+1,Ny*2+1);
Ex_phs = zeros(Nx*2+1,Ny*2+1);
xx = (-Nx:Nx).*Lxi;
yy = (-Ny:Ny).*Lyi;

%------ Initialization ------
oAnsoftApp =  actxserver('AnsoftHfss.HfssScriptInterface');
%oAnsoftApp =  actxserver('AnsoftDesigner.DesignerScript');
oDesktop = oAnsoftApp.GetAppDesktop();
oDesktop.RestoreWindow();
%----------------------------

oDesktop.OpenProject(['D:/HFSS 2014 projects/', ProjectName, '.hfss']);
oProject = oDesktop.SetActiveProject(ProjectName);
oProject.Save();

oDesign = oProject.SetActiveDesign('IEDesign1');
%oDesign = oProject.SetActiveDesign('HFSSDesign1');

fileid = fopen('twoDipoleRCSRedctn_6.txt','a');
%fprintf(fileid,'\t%s\t \t%s\t \t%s\t \t%s\r\n','x(mm)','y(mm)','z(mm)','Ex (in V/m)');
fprintf(fileid,'\t%s\t \t%s\t \t%s\t \t%s\r\n','x(mm)','y(mm)','z(mm)','E_tot (in V/m)');

for i = -Nx:Nx
    for j = -Ny:Ny

    x = i*Lxi;
    y = j*Lyi;
    z = z0;
    r = sqrt(x^2 + y^2 + z^2);
    phi = atan(y/x);
    if (x<0)
        phi = phi + pi;
    end
    if (x==0)
        phi = pi/2;
    end
    theta = acos(z/r);
    r_s = num2str(r,'%10.4f');
    phi_s = num2str(phi*180/pi,'%10.4f');
    theta_s = num2str(theta*180/pi,'%10.4f');
    
    oModule = oDesign.GetModule('RadField');
    oModule.EditNearFieldSphereSetup('Sphere1',{'NAME:Sphere1', ......
	  'UseCustomRadiationSurface:=', false, 'Radius:=', [r_s,'mm'], ......
	  'ThetaStart:=', [theta_s,'deg'], 'ThetaStop:=', [theta_s,'deg'], ......
	  'ThetaStep:=', '0.01deg', 'PhiStart:=', [phi_s,'deg'],  ......
	  'PhiStop:=', [phi_s,'deg'], 'PhiStep:=', '0.01deg', 'UseLocalCS:=', false});
    oProject.Save();
    oModule = oDesign.GetModule('ReportSetup');
    oModule.ExportToFile('Data Table 1', 'D:/HFSS 2014 projects/temp.txt');    
    %oModule.ExportToFile('Data Table 4', 'D:/HFSS 2014 projects/temp.txt');    
    
    A = importdata('D:/HFSS 2014 projects/temp.txt',' ',7);
    %Ex_mag(Nx+1+i,Ny+1+j) = A.data(1,2);        % in V/m
    %Ex_phs(Nx+1+i,Ny+1+j) = A.data(1,3);        % in degrees
    Etot_mag(Nx+1+i,Ny+1+j) = A.data(1,2);        % in V/m
    %fprintf(fileid,'%10.4f\t %10.4f\t %10.4f\t %10.12f\t %10.12f\r\n',x,y,z,Ex_mag(Nx+1+i,Ny+1+j),Ex_phs(Nx+1+i,Ny+1+j));
    fprintf(fileid,'%10.4f\t %10.4f\t %10.4f\t %10.12f\r\n',x,y,z,Etot_mag(Nx+1+i,Ny+1+j));
    
    end
end    

fclose(fileid);
oProject.Save();

E_n = 0.160889;

figure(1)
contourf(xx,yy,Etot_mag./E_n,10)
colorbar
xlabel('\ity\rm in mm')
ylabel('\itx\rm in mm')         
title('\itz\rm = 1.92 m')         

figure(2)
plot(yy,20.*log10((Etot_mag(Nx+1,:))./E_n),'LineWidth',2)  
xlabel('\ity\rm in mm')
ylabel('Normalized \itE_t_o_t_a_l\rm in dB')
title('\itz\rm = 1.92 m, \itx\rm = 0')      % z is the x axis

figure(3)
plot(xx,20.*log10((Etot_mag(:,Ny+1))'./E_n),'LineWidth',2) 
xlabel('\itx\rm in mm')         % actually z axis in this case
ylabel('Normalized \itE_t_o_t_a_l\rm in dB')
title('\itz\rm = 1.92 m, \ity\rm = 0')      % z is the x axis


