% Program to interface with Ansys HFSS and record the E_total in the far field 
% to see the nulling over an observation window at a finite distance

clc; clear all;
format long;            % prints out more digits
format compact;         % makes the output more compact

ProjectName = 'Scattrn_Redctn_FinitePlateTilted_1Dip_DipWv_Lp609p6mm_bistat';
%ProjectName = 'Scattrn_Redctn_FinitePlate_1Dip_PlnWv';

%------ Variables -----------
%Lx = 2000; %  % in millimeters
%Ly = 2000; %  % in millimeters
%Nx = 40;
%Ny = 40;
%Lxi = Lx/Nx;
%Lyi = Ly/Ny;
z0 = 1219.2;  %1407.81; %1920;     %50000; %1900; % in millimeters
%Ex_mag = zeros(Nx*2+1,Ny*2+1);
%Ex_phs = zeros(Nx*2+1,Ny*2+1);
%xx = (-Nx:Nx).*Lxi;
%yy = (-Ny:Ny).*Lyi;

xx = -160:4:160;
yy = 300:5:1000;
Nx = length(xx);
Ny = length(yy);
Ex_mag = zeros(Ny,Nx);
Ex_phs = zeros(Ny,Nx);

%------ Initialization ------
oAnsoftApp =  actxserver('AnsoftHfss.HfssScriptInterface');
oDesktop = oAnsoftApp.GetAppDesktop();
oDesktop.RestoreWindow();
%----------------------------

oDesktop.OpenProject(['D:/HFSS 2014 projects/', ProjectName, '.hfss']);
oProject = oDesktop.SetActiveProject(ProjectName);
oProject.Save();

oDesign = oProject.SetActiveDesign('HFSSDesign1');

fileid = fopen('FinitePlate_1Dip_1DipWv_1.txt','a');
fprintf(fileid,'\t%s\t \t%s\t \t%s\t \t%s\t \t%s\t \t%s\t \t%s\r\n', .......
                'x(mm)','y(mm)','z(mm)','theta(rad)','phi(rad)','r(mm)','Ex (in V/m)');
%fprintf(fileid,'\t%s\t \t%s\t \t%s\t \t%s\r\n','x(mm)','y(mm)','z(mm)','E_tot (in V/m)');

for i = 1:Nx
    for j = 1:Ny

    x = xx(i);
    y = -yy(j);
    z = z0;
    r = sqrt(x^2 + y^2 + z^2);
    phi = atan(y/x) + 2*pi;
    if (x<0)
        phi = phi - pi;
    end
    if (x==0)
        phi = 3*pi/2;
    end
    theta = acos(z/r);
    r_s = num2str(r,'%10.4f');
    phi_s = num2str(phi*180/pi,'%10.4f');
    theta_s = num2str(theta*180/pi,'%10.4f');
    
    oModule = oDesign.GetModule('RadField');
    oModule.EditNearFieldSphereSetup('Sphere1',{'NAME:Sphere1', ......
	  'UseCustomRadiationSurface:=', false, 'Radius:=', [r_s,'mm'], ......
	  'ThetaStart:=', [theta_s,'deg'], 'ThetaStop:=', [theta_s,'deg'], ......
	  'ThetaStep:=', '0.01deg', 'PhiStart:=', [phi_s,'deg'],  ......
	  'PhiStop:=', [phi_s,'deg'], 'PhiStep:=', '0.01deg', 'UseLocalCS:=', false});
    oProject.Save();
    oModule = oDesign.GetModule('ReportSetup');
    oModule.ExportToFile('Data Table 2', 'D:/HFSS 2014 projects/temp.txt');    
    %oModule.ExportToFile('Data Table 4', 'D:/HFSS 2014 projects/temp.txt');    
    
    A = importdata('D:/HFSS 2014 projects/temp.txt',' ',7);
    Ex_mag(j,i) = A.data(1,2);        % in V/m
    Ex_phs(j,i) = A.data(1,3);        % in rad
    %Etot_mag(Nx+1+i,Ny+1+j) = A.data(1,2);        % in V/m
    fprintf(fileid,'%10.4f\t %10.4f\t %10.4f\t %10.4f\t %10.4f\t %10.4f\t %10.12f\t %10.12f\r\n' .......
            ,x,y,z,theta,phi,r,Ex_mag(j,i),Ex_phs(j,i));
    %fprintf(fileid,'%10.4f\t %10.4f\t %10.4f\t %10.12f\r\n',x,y,z,Etot_mag(Nx+1+i,Ny+1+j));
    
    end
end    

fclose(fileid);
oProject.Save();

E_n = 1136.180794;  %1137.716373;    % 1336

figure(1)
contourf(yy,xx,Ex_mag'./E_n,10)
colorbar
xlabel('\ity\rm in mm')
ylabel('\itx\rm in mm')         
title('\itz\rm = 4 ft')         

figure(2)
plot(yy,20.*log10((Ex_mag(:,(Nx+1)/2))'./E_n),'LineWidth',2)  
xlabel('\ity\rm in mm')
ylabel('Normalized \itE_t_o_t_a_l\rm in dB')
title('\itz\rm = 4 ft, \itx\rm = 0')      % z is the x axis

figure(3)
plot(xx,20.*log10((Ex_mag((Ny+1)/2,:))./E_n),'LineWidth',2) 
xlabel('\itx\rm in mm')         % actually z axis in this case
ylabel('Normalized \itE_t_o_t_a_l\rm in dB')
title('\itz\rm = 4 ft, \ity\rm = 0')      % z is the x axis
