% SCATTERING OF LINEARLY POLARIZED (x direction) INCIDENT PLANE WAVE FROM A SPHERE
% take the origin to be the center of the sphere
% wave is propagating in the z direction

clc; 
clear all;
format long;            % prints out more digits
format compact;         % makes the output more compact

f = 1.575e9;  %12e9;  %
c = 299792458;
lambda = c/f;
mu0 = 4*pi*(1e-7);
eps0 = 1/mu0/(c^2);
eta0 = sqrt(mu0/eps0);
k0 = (2*pi).*f.*sqrt(eps0*mu0);
omega = 2*pi*f;
N = 50;
a = 9.52e-2;   % radius of the sphere
theta = 0*pi/180;  % angle at which field is measured
phi = 0*pi/180;  % angle at which field is measured
E0 = 1;
r = lambda;        %19.9844;
z = r*cos(theta);
h = 0.0001;   % difference (or deltaX for the derivative w.r.t. X)

Pnd = zeros(1,N+1);
Pnd2 = zeros(1,N+1);
c = zeros(1,N+1);
d = zeros(1,N+1);
e = zeros(1,N+1);
for n = 0:N
   if (n == 0)
     c(1,n+1) = 0;
   else
     c(1,n+1) = (((-1i)^n)/omega)*(2*n+1)/(n*(n+1));
   end
   d(1,n+1) = -c(1,n+1)*((n+1)*besselj(n+0.5,k0*a)-(k0*a)*besselj(n+1.5,k0*a))/.....
        ((n+1)*besselh(n+0.5,2,k0*a)-(k0*a)*besselh(n+1.5,2,k0*a));
   e(1,n+1) = -c(1,n+1)*besselj(n+0.5,k0*a)/besselh(n+0.5,2,k0*a);   
   if (cos(theta) == 1)
      % Calculating 1st derivative
      P1 = legendre(n,cos(theta)-h);
      P2 = legendre(n,cos(theta));
      Pnd(1,n+1) = (P2(1,1) - P1(1,1))/h;
      % Calculating 2nd derivative
      P1 = legendre(n,cos(theta)-h*2);
      P2 = legendre(n,cos(theta));
      P = legendre(n,cos(theta)-h);
      Pnd2(1,n+1) = (P2(1,1) - 2*P(1,1) + P1(1,1))/(h*h);   
   else
    if (cos(theta) == -1)
      % Calculating 1st derivative
      P1 = legendre(n,cos(theta));
      P2 = legendre(n,cos(theta)+h);
      Pnd(1,n+1) = (P2(1,1) - P1(1,1))/h;
      % Calculating 2nd derivative
      P1 = legendre(n,cos(theta));
      P2 = legendre(n,cos(theta)+h*2);
      P = legendre(n,cos(theta)+h);
      Pnd2(1,n+1) = (P2(1,1) - 2*P(1,1) + P1(1,1))/(h*h);  
    else
      % Calculating 1st derivative
      P1 = legendre(n,cos(theta)-h/2);
      P2 = legendre(n,cos(theta)+h/2);
      Pnd(1,n+1) = (P2(1,1) - P1(1,1))/h;
      % Calculating 2nd derivative
      P1 = legendre(n,cos(theta)-h);
      P2 = legendre(n,cos(theta)+h);
      P = legendre(n,cos(theta));
      Pnd2(1,n+1) = (P2(1,1) - 2*P(1,1) + P1(1,1))/(h*h);           
    end    
   end        
end
nv = 0:N;

Ei_th = E0*cos(phi)*cos(theta)*exp(-1i*k0*z);
Ei_ph = -E0*sin(phi)*exp(-1i*k0*z);

Es_th = (E0*cos(phi)/(eps0*eta0))*(exp(-1i*k0*r)/r)*sum(e.*(1i.^(nv+1)).*Pnd) ......
    - (E0*cos(phi)/(1i*omega*mu0*eps0))*(exp(-1i*k0*r)/r)*sum(d.*k0.*(1i.^nv).*(cos(theta).*Pnd .....
       - ((sin(theta)).^2).*Pnd2));
Es_ph = -(E0*sin(phi)/(eps0*eta0))*(exp(-1i*k0*r)/r)*sum(e.*(1i.^(nv+1)).*(cos(theta).*Pnd - ......
 ((sin(theta)).^2).*Pnd2)) + (E0*sin(phi)/(1i*omega*mu0*eps0))*(exp(-1i*k0*r)/r)*sum(d.*k0.*(1i.^nv).*Pnd);
    

E_th = Ei_th + Es_th;
E_ph = Ei_ph + Es_ph;

disp(r*Es_th)
disp(r*Es_ph)

RCSphi = 4*pi*r*r*((abs(Es_ph))^2)/((abs(Ei_th))^2+(abs(Ei_ph))^2);
RCStheta = 4*pi*r*r*((abs(Es_th))^2)/((abs(Ei_th))^2+(abs(Ei_ph))^2);

disp(RCSphi)
disp(RCStheta)
